Arena
Armory
Terrain
Skills
Vendor
Allies
Miscellany
WeaponBonuses
Support
Affinity
ItemBonuses
ArmedMorph

ArmedMorph
- Armory
- Support
- Skills
- ItemBonus
- WeaponBonus

Arena
- Terrain
- Skills

implement combat mechanics
round-up or round-down
input manually, alternatively
attack (self, aenemy, weapon, terrain)
